diff mbox

When a disk needs to be waken up from sleep, ensure that the command is retried by SCSI EH.

Message ID 1249684013-24307-1-git-send-email-gwendal@google.com
State Not Applicable
Delegated to: David Miller
Headers show

Commit Message

Gwendal Grignou Aug. 7, 2009, 10:26 p.m. UTC
---
 drivers/ata/libata-eh.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

Comments

Tejun Heo Aug. 7, 2009, 10:37 p.m. UTC | #1
Gwendal Grignou wrote:
> ---
>  drivers/ata/libata-eh.c |    6 +++---
>  1 files changed, 3 insertions(+), 3 deletions(-)

The patch description is missing again but other than that

Acked-by: Tejun Heo <tj@kernel.org>
diff mbox

Patch

diff --git a/drivers/ata/libata-eh.c b/drivers/ata/libata-eh.c
index 79711b6..202da9c 100644
--- a/drivers/ata/libata-eh.c
+++ b/drivers/ata/libata-eh.c
@@ -1183,14 +1183,14 @@  void ata_eh_qc_complete(struct ata_queued_cmd *qc)
  *	should be retried.  To be used from EH.
  *
  *	SCSI midlayer limits the number of retries to scmd->allowed.
  *	scmd->retries is decremented for commands which get retried
  *	due to unrelated failures (qc->err_mask is zero).
  */
 void ata_eh_qc_retry(struct ata_queued_cmd *qc)
 {
 	struct scsi_cmnd *scmd = qc->scsicmd;
-	if (!qc->err_mask && scmd->retries)
-		scmd->retries--;
+	if (!qc->err_mask)
+		scmd->allowed++;
 	__ata_eh_qc_complete(qc);
 }
@@ -1183,14 +1183,14 @@  void ata_eh_qc_complete(struct ata_queued_cmd *qc)
  *
  *	SCSI midlayer limits the number of retries to scmd->allowed.
- *	scmd->retries is decremented for commands which get retried
+ *	scmd->allowed is incremented for commands which get retried
  *	due to unrelated failures (qc->err_mask is zero).
  */